Most content has moved to the temporary website https://oscovida.github.io

The remaining content here is only for developers.

![tests](https://github.com/oscovida/oscovida/workflows/tests/badge.svg)
![Generate Webpage](https://github.com/oscovida/oscovida/workflows/Generate%20Webpage/badge.svg)
[![codecov](https://codecov.io/gh/oscovida/oscovida/branch/master/graph/badge.svg)](https://codecov.io/gh/oscovida/oscovida)
[![project chat](https://img.shields.io/badge/zulip-join_chat-brightgreen.svg)](https://oscovida.zulipchat.com)

--------------------------------


# Disclaimer

The plots and code here has been put together by volunteers who have no training
in epidemiology. THere are likely to be errors in the processing. You are welcome
to use the material at your own risk. The [license is available](LICENSE).


# Acknowledgements

- Johns Hopkins University provides data for countries
- Robert Koch Institute provides data for within Germany
- Open source and scientific computing community for the data tools
- Github for hosting repository and html files
- Project Jupyter for the Notebook and Binder service
- The H2020 project Photon and Neutron Open Science Cloud ([PaNOSC](https://www.panosc.eu/))
